pub enum KeyboardButtonType {
RequestLocation(KeyboardButtonTypeRequestLocation),
RequestPhoneNumber(KeyboardButtonTypeRequestPhoneNumber),
RequestPoll(KeyboardButtonTypeRequestPoll),
Text(KeyboardButtonTypeText),
// some variants omitted
}Expand description
Describes a keyboard button type
Variants
RequestLocation(KeyboardButtonTypeRequestLocation)
Tuple Fields
A button that sends the user’s location when pressed; available only in private chats
RequestPhoneNumber(KeyboardButtonTypeRequestPhoneNumber)
Tuple Fields
A button that sends the user’s phone number when pressed; available only in private chats
RequestPoll(KeyboardButtonTypeRequestPoll)
Tuple Fields
A button that allows the user to create and send a poll when pressed; available only in private chats
Text(KeyboardButtonTypeText)
Tuple Fields
A simple button, with text that must be sent when the button is pressed
Implementations
pub fn on_request_location<F: FnOnce(&KeyboardButtonTypeRequestLocation)>(
&self,
fnc: F
) -> &Self
pub fn on_request_phone_number<F: FnOnce(&KeyboardButtonTypeRequestPhoneNumber)>(
&self,
fnc: F
) -> &Self